%global other_name annotations
%global pkg_name java-%{other_name}

Name:           jetbrains-%{pkg_name}
Version:        22.0.0
Release:        1%{?dist}
Summary:        A set of annotations used for code inspection support and code documentation
License:        ASL 2.0
URL:            https://github.com/JetBrains/java-annotations
BuildArch:      noarch
Source0:        %{url}/archive/%{version}.tar.gz
Source1:        https://repo1.maven.org/maven2/org/jetbrains/%{other_name}/%{version}/%{other_name}-%{version}.pom

BuildRequires:  maven-local
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)

%description
A set of Java annotations which can be used in JVM-based languages. They serve
as an additional documentation and can be interpreted by IDEs and static
analysis tools to improve code analysis.

%javadoc_package

%prep
%autosetup -n %{pkg_name}-%{version}

find -type f '(' -name '*.jar' -o -name '*.class' ')' -delete

cp %{SOURCE1} pom.xml

%pom_xpath_inject pom:project '
<properties>
  <project.build.sourceEncoding>UTF-8</project.build.sourceEncoding>
</properties>'

%pom_add_plugin org.codehaus.mojo:build-helper-maven-plugin '
<executions>
  <execution>
    <id>add-source</id>
    <phase>generate-sources</phase>
    <goals>
      <goal>add-source</goal>
    </goals>
    <configuration>
      <sources>
        <source>common</source>
        <source>java8</source>
        <source>module-info</source>
      </sources>
    </configuration>
  </execution>
</executions>'

%pom_add_plugin :maven-resources-plugin '
<executions>
  <execution>
    <id>copy-resources</id>
    <phase>prepare-package</phase>
    <goals>
      <goal>copy-resources</goal>
    </goals>
    <configuration>
      <outputDirectory>${project.build.outputDirectory}/META-INF/versions/9</outputDirectory>
      <resources>
        <resource>
          <directory>target/classes-java9</directory>
          <includes>
            <include>**/module-info.class</include>
          </includes>
        </resource>
      </resources>
    </configuration>
  </execution>
</executions>'

%pom_add_plugin :maven-jar-plugin '
<configuration>
  <archive>
    <manifestEntries>
      <Multi-Release>true</Multi-Release>
    </manifestEntries>
  </archive>
</configuration>'

%pom_add_plugin :maven-compiler-plugin '
<executions>
  <execution>
    <id>default-compile</id>
    <configuration>
      <outputDirectory>target/classes</outputDirectory>
      <excludes>
        <exclude>**/module-info.java</exclude>
      </excludes>
    </configuration>
  </execution>
  <execution>
    <id>base-compile</id>
    <goals>
      <goal>compile</goal>
    </goals>
    <configuration>
      <outputDirectory>target/classes-java9</outputDirectory>
      <jdkToolchain>
        <version>9</version>
      </jdkToolchain>
      <release>9</release>
    </configuration>
  </execution>
</executions>'

%build
%mvn_build -- -Dmaven.compiler.source=1.8 -Dmaven.compiler.target=1.8

%install
%mvn_install

%files -f .mfiles
%license LICENSE.txt
%doc README.md CONTRIBUTING.md CODE_OF_CONDUCT.md CHANGELOG.md

%changelog
* Fri Sep 17 2021 Didik Supriadi <didiksupriadi41@gmail.com> - 22.0.0-1
- Initial package
